@@ -13,6 +13,7 @@
 
 
 from mktxp.datasource.base_ds import BaseDSProcessor
+from mktxp.datasource.package_ds import PackageMetricsDataSource
 
 
 class WirelessMetricsDataSource:
@@ -23,10 +24,21 @@ class WirelessMetricsDataSource:
         if metric_labels is None:
             metric_labels = []                
         try:
-            registration_table_records = router_entry.api_connection.router_api().get_resource('/interface/wireless/registration-table').get()
-            return BaseDSProcessor.trimmed_records(router_entry, router_records = registration_table_records, metric_labels = metric_labels, add_router_id = add_router_id)
+            wireless_package = WirelessMetricsDataSource.wireless_package(router_entry)
+            registration_table_records = router_entry.api_connection.router_api().get_resource(f'/interface/{wireless_package}/registration-table').get()
+
+            # Mikrotik renamed the field 'signal_strength' to 'signal' when using wifiwave2.
+            # Rename this field back to 'signal_strength' to preserve backwards compatibility
+            for record in registration_table_records:
+                if 'signal' in record:
+                    record['signal_strength'] = record['signal']
+
+            return BaseDSProcessor.trimmed_records(router_entry, router_records = registration_table_records, metric_labels = metric_labels, add_router_id = add_router_id,)
         except Exception as exc:
             print(f'Error getting wireless registration table info from router{router_entry.router_name}@{router_entry.config_entry.hostname}: {exc}')
             return None
 
 
+    @staticmethod
+    def wireless_package(router_entry):
+        return 'wifiwave2' if PackageMetricsDataSource.is_package_installed(router_entry, package_name = 'wifiwave2') else 'wireless'
