@@ -33,11 +33,11 @@ class BaseOutputProcessor:
     @staticmethod
     def augment_record(router_entry, registration_record, dhcp_lease_records):
         try:
-            dhcp_lease_record = next((dhcp_lease_record for dhcp_lease_record in dhcp_lease_records if dhcp_lease_record['mac_address']==registration_record['mac_address']))
+            dhcp_lease_record = next((dhcp_lease_record for dhcp_lease_record in dhcp_lease_records if dhcp_lease_record.get('mac_address')==registration_record.get('mac_address')))
             dhcp_name = BaseOutputProcessor.dhcp_name(router_entry, dhcp_lease_record)
             dhcp_address = dhcp_lease_record.get('address', '')
         except StopIteration:
-            dhcp_name = registration_record['mac_address']
+            dhcp_name = registration_record.get('mac_address')
             dhcp_address = 'No DHCP Record'          
 
         registration_record['dhcp_name'] = dhcp_name
@@ -85,7 +85,7 @@ class BaseOutputProcessor:
             wifi_rates_rgx = re.compile(r'(\d*(?:\.\d*)?)([GgMmKk]bps?)')
             config_handler.re_compiled['wifi_rates_rgx'] = wifi_rates_rgx
         rc = wifi_rates_rgx.search(rate)
-        return f'{int(float(rc[1]))} {rc[2]}' if rc else ''
+        return f'{int(float(rc[1]))} {rc[2]}' if rc and len(rc.groups()) == 2 else rate
 
     @staticmethod
     def parse_timedelta(time):
