@@ -31,6 +31,8 @@ class RouterEntry:
                             'SystemResourceCollector': 0,
                             'HealthCollector': 0,
                             'PublicIPAddressCollector': 0,
+                            'IPv6NeighborCollector': 0,
+                            'PackageCollector': 0,
                             'DHCPCollector': 0,
                             'PoolCollector': 0,
                             'IPConnectionCollector': 0,
@@ -42,5 +44,8 @@ class RouterEntry:
                             'RouteCollector': 0,
                             'WLANCollector': 0,
                             'CapsmanCollector': 0,
+                            'QueueTreeCollector': 0,
+                            'QueueSimpleCollector': 0,                            
+                            'UserCollector': 0,                            
                             'MKTXPCollector': 0
                             }            
